@@ -54,6 +54,13 @@ function Graph() {
             .attr("width", this.w)
             .attr("height", this.h)
             .attr("id", this.id);
+
+        this.tooltip = this.div.append('div')
+            .style('position', 'absolute')
+            .style('background', '#000000')
+            .style('padding', '3px')
+            .style('color', '#ffffff')
+            .style('opacity', .0);
     };
 
     this.close = function() {
@@ -209,7 +216,7 @@ function TimePlot() {
                 this.y_scale_type_input.attr("value", "log");
                 break;
         }
-        this.yAxis = d3.svg.axis().scale(this.yScale).orient("left").ticks(5)
+        this.yAxis = d3.svg.axis().scale(this.yScale).orient("left").ticks(8)
             .tickSize(-(this.w - this.padding - this.padding_left), 0, 0);
     };
 
@@ -236,7 +243,7 @@ function TimePlot() {
                                   .tickSize(-(this.h - 2*this.padding), 0, 0)
                                   .tickPadding(8)
                                   .tickFormat(timeFormat);
-        this.yAxis = d3.svg.axis().scale(this.yScale).orient("left").ticks(5)
+        this.yAxis = d3.svg.axis().scale(this.yScale).orient("left").ticks(8)
                                   .tickSize(-(this.w - this.padding - this.padding_left), 0, 0);
 
         this.svg.append("g")
@@ -310,6 +317,17 @@ function TimePlot() {
                           return "none";
                       }
                   })
+                  .on('mouseover', function(d) {
+                      self.tooltip.text(parameter_type)
+                          .style('opacity', 0.9)
+                          .style('left', (d3.event.pageX - 190) + 'px')
+                          .style('top', (d3.event.pageY - 60) + 'px');
+                      d3.select(this).style("stroke-width", 3);
+                  })
+                  .on('mouseout', function(d) {
+                      self.tooltip.style('opacity', 0.0);
+                      d3.select(this).style("stroke-width", 1);
+                  })
                   .transition()
                   .ease("linear")
                   .duration(self.smoothness)
@@ -368,9 +386,14 @@ function TimePlot() {
         if(this.line_enabled) {
             this.draw_lines();
         }
+        var units = [];
         self.parameter_types.forEach(function(parameter_type) {
-            self.y_label.text(window.parameters[parameter_type][0].unit);
+            var unit = window.parameters[parameter_type][0].unit;
+            if(!roy.tools.includes(units, unit)) {
+                units.push(window.parameters[parameter_type][0].unit);
+            }
         });
+        self.y_label.text(units.join(', '));
     };
 
 
@@ -416,7 +439,7 @@ function Histogram() {
         this.xAxis = d3.svg.axis().scale(this.xScale).orient("bottom").ticks(5)
             .tickSize(-(this.h - 2*this.padding), 0, 0)
             .tickPadding(8);
-        this.yAxis = d3.svg.axis().scale(this.yScale).orient("left").ticks(5)
+        this.yAxis = d3.svg.axis().scale(this.yScale).orient("left").ticks(8)
             .tickSize(-(this.w - this.padding - this.padding_left), 0, 0);
 
         this.svg.append("g")
@@ -484,7 +507,22 @@ function Histogram() {
             .attr("height", function(d) { return (self.yScale(0) - self.yScale(d.y)); })
             //.attr("class", function(d) { return d.type; })
             //.attr("fill", function(d) { return self.parameter_color(d.type); });
-            .attr("fill", "#2688D3");
+            .attr("fill", "#2688D3")
+            .on('mouseover', function(d) {
+                d3.select(this).attr('fill', '#FF5179');
+                //d3.select(this).style('opacity', 0.5);
+                self.tooltip.text(d.y)
+                    .style('opacity', 0.9)
+                    .style('left', (d3.event.pageX - 190) + 'px')
+                    .style('top', (d3.event.pageY - 60) + 'px');
+            })
+            .on('mouseout', function(d) {
+                d3.select(this).attr('fill', '#2688D3');
+                //d3.select(this).style('opacity', 1.0);
+                self.tooltip.style('opacity', 0.0);
+            })
+            .on('click', function() {
+            });
 
         bars.transition()
             .duration(this.smoothness)
@@ -505,9 +543,16 @@ function Histogram() {
         this.histogram = d3.layout.histogram().bins(this.nbins)(this.map);
         this.draw_axes();
         this.draw_bars();
+
+        var units = [];
         self.parameter_types.forEach(function(parameter_type) {
-            self.x_label.text(window.parameters[parameter_type][0].unit);
+            var unit = window.parameters[parameter_type][0].unit;
+            if(!roy.tools.includes(units, unit)) {
+                units.push(window.parameters[parameter_type][0].unit);
+            }
         });
+        self.x_label.text(units.join(', '));
+
     };
 
 
